@@ -192,7 +192,7 @@ PARALLEL <- function(x = NULL,
       }
 
       # Check if correlation matrix is positive definite
-      if(any(eigen(R)$values <= 0)){
+      if(any(eigen(R)$values <= .Machine$double.eps^.6)){
 
         R <- psych::cor.smooth(R)
 
